# knn_fishmlserv

# command
```bash
$ knn_fishml
$ 나가기를 원하면 exit을 입력하세요
$ 물고기의 길이를 입력하세요: 35
$ 물고기의 무게를 입력하세요: 37
$ 이 녀석은 바로 도미
$ 정답을 입력하세요: 도미
$ 물고기의 길이를 입력하세요: 35.7
$ 물고기의 무게를 입력하세요: 27.8
$ 이 녀석은 바로 도미
$ 정답을 입력하세요: 도미
$ 물고기의 길이를 입력하세요: 1
$ 물고기의 무게를 입력하세요: 1
$ 이 녀석은 바로 도미
$ 정답을 입력하세요: 빙어
$ 물고기의 길이를 입력하세요: 3
$ 물고기의 무게를 입력하세요: 2
$ 이 녀석은 바로 도미
$ 정답을 입력하세요: 빙어
$ 물고기의 길이를 입력하세요: 3
$ 물고기의 무게를 입력하세요: 4
$ 이 녀석은 바로 도미
$ 정답을 입력하세요: 빙어
$ 물고기의 길이를 입력하세요: 2
$ 물고기의 무게를 입력하세요: 5
$ 이 녀석은 바로 도미
$ 정답을 입력하세요: 빙어
$ 물고기의 길이를 입력하세요: 3
$ 물고기의 무게를 입력하세요: 6
$ 이 녀석은 바로 빙어
$ 정답을 입력하세요: 빙어
$ 물고기의 길이를 입력하세요: exit
$ 프로그램을 종료합니다.
```

